@@ -342,8 +342,9 @@ levelfun <- function(x, nl.n, allow.new.levels=FALSE) {
 ##'    the prediction will use the unconditional (population-level)
 ##'    values for data with previously unobserved levels (or \code{NA}s)
 ##' @param na.action function determining what should be done with missing values for fixed effects in \code{newdata}. The default is to predict \code{NA}: see \code{\link{na.pass}}.
+##' @param se.fit A logical value indicating whether the standard errors should be included or not. Default is FALSE.
 ##' @param ... optional additional parameters.  None are used at present.
-##' @return a numeric vector of predicted values
+##' @return a numeric vector of predicted values, unless \code{se.fit=TRUE} (in which case a list with elements \code{fit} (predicted values) and \code{se.fit} is returned)
 ##' @note There is no option for computing standard errors of predictions because it is difficult to define an efficient method that incorporates uncertainty in the variance parameters; we recommend \code{\link{bootMer}} for this task.
 ##' @examples
 ##' (gm1 <- glmer(cbind(incidence, size - incidence) ~ period + (1 |herd), cbpp, binomial))
@@ -362,7 +363,8 @@ predict.merMod <- function(object, newdata=NULL, newparams=NULL,
                            REform,
                            random.only=FALSE,
                            terms=NULL, type=c("link","response"),
-                           allow.new.levels=FALSE, na.action=na.pass, ...) {
+                           allow.new.levels=FALSE, na.action=na.pass,
+                           se.fit = FALSE, ...) {
     ## FIXME: appropriate names for result vector?
     ## FIXME: make sure behaviour is entirely well-defined for NA in grouping factors
 
@@ -521,7 +523,59 @@ predict.merMod <- function(object, newdata=NULL, newparams=NULL,
                 class(fit.na.action) <- class(attr(na.action(NA),"na.action"))
         }
     }
-    napredict(fit.na.action, pred)
+    pred <- napredict(fit.na.action, pred)
+
+    if (!se.fit) return(pred)
+
+    if (!isLMM(object)) warning("se.fit computation uses an approximation to estimate the sampling distribution of the parameters")
+    
+    s <- sigma(object)
+    ## need these below so can't getME(...) all at once
+    L <- getME(object, "L")
+    RX <- getME(object, "RX")
+    RZX <- getME(object, "RZX")
+    Lambdat <- getME(object, "Lambdat")
+
+    RXtinv <- solve(t(RX))
+    LinvLambdat <- solve(L, Lambdat, system = "L")
+    Minv <- s * rbind(
+                    cbind(LinvLambdat,
+                          Matrix(0, nrow = nrow(L), ncol = ncol(RX))),
+                    cbind(-RXtinv %*% t(RZX) %*% LinvLambdat, RXtinv)
+                )
+    Cmat <- crossprod(Minv)
+        
+        
+    ## FIXME: these need to be fixed
+    if(is.null(newdata)) {
+        X <- getME(object, "X")
+        if(is.null(re.form)) {
+            Z <- getME(object, "Z")
+        } else {
+            if(isRE(re.form)) {
+                ## FIXME: newRE is not computed here
+                Z <- t(newRE$Zt)
+            } else {
+                Z <- Matrix(0, nrow = nrow(X), ncol = ncol(L))
+            }
+        }
+    } else {
+        if(isRE(re.form)) {
+            Z <- t(newRE$Zt)
+        } else {
+            ## this is inefficient and we could just calculate 
+            ## X %*% Cmat[X part only] t(X) instead
+            Z <- Matrix(0, nrow = nrow(X), ncol = ncol(L))
+        }
+    }
+        
+    if(random.only) X <- Matrix(0, nrow = nrow(Z), ncol = nrow(RX))
+        
+    ZX <- cbind(Z, X)
+    list(fit = pred,
+         se.fit = sqrt(quad.tdiag(Cmat, ZX))
+         )
+    
 } # end {predict.merMod}
 
 
