@@ -14,7 +14,7 @@ library("lattice")
 library("minqa")
 opts_chunk$set(engine='R',dev='pdf', fig.width=9, fig.height=5.5,
                prompt=TRUE, cache=TRUE, tidy=FALSE, comment=NA)
-render_sweave()
+knitr::render_sweave()
 
 ## ----sleep----------------------------------------------------------
 str(sleepstudy)
