@@ -16,7 +16,7 @@ d$eta <- d$eta0+reff_f[d$block]
 d$mu <- d$eta
 d$y <- rnorm(nrow(d),mean=d$mu,sd=1)
 
-fm1 <- lmer(y~x+(1|block),data=d)
+fm1    <- lmer(y~x+(1|block),            data=d)
 fm1off <- lmer(y~x+(1|block)+offset(3*x),data=d)
 
 ## check equality
@@ -25,15 +25,16 @@ stopifnot(all.equal(fixef(fm1)[2]-3,fixef(fm1off)[2]))
 p0 <- predict(fm1)
 p1 <- predict(fm1,newdata=d)
 p2 <- predict(fm1off,newdata=d)
-stopifnot(all.equal(p0,p1,p2))
+stopifnot(all.equal(p0,p1),
+          all.equal(p1,p2))
 
 
 ## glmer() test:
 d$mu <- exp(d$eta)
 d$y <- rpois(nrow(d),d$mu)
 
-gm1 <- glmer(y~x+(1|block),data=d,family=poisson,
-             control=glmerControl(check.conv.grad="ignore"))
+gm1    <- glmer(y~x+(1|block),            data=d,family=poisson,
+                control=glmerControl(check.conv.grad="ignore"))
 gm1off <- glmer(y~x+(1|block)+offset(3*x),data=d,family=poisson,
                 control=glmerControl(check.conv.grad="ignore"))
 
@@ -43,7 +44,8 @@ stopifnot(all.equal(fixef(gm1)[2]-3,fixef(gm1off)[2],tolerance=3e-4))
 p0 <- predict(gm1)
 p1 <- predict(gm1,newdata=d)
 p2 <- predict(gm1off,newdata=d)
-stopifnot(all.equal(p0,p1,p2))
+stopifnot(all.equal(p0,p1),
+          all.equal(p1,p2))
 
 ## FIXME: should also test simulations
 } ## skip on windows (for speed)
