@@ -363,8 +363,14 @@ test_that("test for zero non-NA cases", {
 })
 
 ##
-test_that("catch matrix-valued responses", {
+test_that("catch matrix-valued responses in lmer/glmer but not in formulas", {
     dd <- data.frame(x = rnorm(1000), batch = factor(rep(1:20, each=50)))
     dd$y <- matrix(rnorm(1e4), ncol = 10)
+    dd$y2 <- matrix(rpois(1e4, lambda = 1), ncol = 10)
     expect_error(lmer(y ~ x + (1|batch), dd), "matrix-valued")
+    fr <- lFormula(y ~ x + (1|batch), dd)$fr
+    expect_true(is.matrix(model.response(fr)))
+    expect_error(glmer(y ~ x + (1|batch), dd, family = poisson), "matrix-valued")
+    fr <- glFormula(y ~ x + (1|batch), dd, family = poisson)$fr
 })
+
